@@ -175,12 +175,17 @@ def plot_image (app, plot):
         outfullfn = path.join(app.builder.outdir, app.builder.imagedir, outfname),
         outreference = None)
 
+    #print("cmd: %s" %(cmd))
     if "ditaa" in cmd:
-        if plot_format in ["svg", "pdf"]:
-            args.insert(1, "--svg") #ditaa support vector image by --svg parameter.
+        args.insert(1, "--svg") #to support Chinese, draw it always with --svg.
         args.extend([infname, outfname])
         # Ditaa must work on the target directory.
         os.chdir(os.path.dirname(out["outfullfn"]))
+    if "seqdiag" in cmd: #seqdiag only support svg, convert it to pdf automatically.
+        if (plot_format in ["svg", "pdf"]) and ("-Tsvg" not in cmd):
+            args.insert(1, "-Tsvg") #ditaa support vector image by --svg parameter.
+            os.chdir(os.path.dirname(out["outfullfn"]))
+        args.extend([infname, '-o', outfname])
     elif args[0] == "dot":
         # dot -Tpng in_file -o out_file
         args.extend([infullfn, '-o', out["outfullfn"]])
@@ -262,7 +267,8 @@ def plot_image (app, plot):
         c += " %s" %(out["outfullfn"])
         print(c)
         os.system(c)
-    if (args[0] == "ditaa") and (plot_format in ['pdf']):
+    if (args[0] == "ditaa" or args[0] == "seqdiag") and\
+            (plot_format in ['pdf']):
         # In fact ditaa don't support pdf, we convert the .svg to .pdf inkscape
         print("mv %s %s-%s.svg" %(outfname, args[0], hashkey))
         os.system("mv %s %s-%s.svg" %(outfname, args[0], hashkey))
